==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/en.js <==
﻿/*
 * English language file.
 *
 * Initial Author: Artem Lopata (mod-s@yandex.ru)
 *
 * Author: 
 */

var theUILang =
{
 General			: "General",
 Downloads			: "Downloads",
 Connection			: "Connection",
 BitTorrent			: "BitTorrent",
 Advanced			: "Advanced",
 User_Interface 		: "User Interface",
 Confirm_del_torr		: "Confirm when deleting torrents",
 Update_GUI_every		: "Update GUI every",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternate list background colour",
 Show_cat_start 		: "Show categories on startup",
 Show_det_start 		: "Show details on startup",
 Dnt_start_down_auto		: "Don't start the download automatically",
 Listening_Port 		: "Listening Port",
 Port_f_incom_conns		: "Port used for incoming connections",
 Rnd_port_torr_start		: "Randomize port each time rTorrent starts",
 Type				: "Type",
 Bandwidth_Limiting		: "Bandwidth Limiting",
 Global_max_upl 		: "Global maximum upload rate",
 unlimited			: "Unlimited",
 Glob_max_downl 		: "Global maximum download rate",
 Add_bittor_featrs		: "Additional BitTorrent Features",
 En_DHT_ntw			: "Enable DHT Network",
 Peer_exch			: "Peer Exchange",
 Ip_report_track		: "IP/Hostname to report to tracker",
 Disabled			: "Disabled",
 Enabled			: "Enabled",
 ruTorrent_settings		: "Settings",
 Doesnt_support 		: "ruTorrent does not support your browser.",
 Name				: "Name",
 Status 			: "Status",
 Size				: "Size",
 Done				: "Done",
 Downloaded			: "Downloaded",
 Uploaded			: "Uploaded",
 Ratio				: "Ratio",
 DL				: "DL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Label",
 Peers				: "Peers",
 Seeds				: "Seeds",
 Remaining			: "Remaining",
 Priority			: "Priority",
 Not_torrent_file		: "The file must be a .torrent file.",
 Pausing			: "Pausing",
 Seeding			: "Seeding",
 Downloading			: "Downloading",
 Checking			: "Checking",
 Error				: "Error",
 Queued 			: "Queued",
 Finished			: "Completed",
 Stopped			: "Stopped",
 Request_timed_out		: "The request to rTorrent has timed out.",
 Start				: "Start",
 Pause				: "Pause",
 Stop				: "Stop",
 Force_recheck			: "Force Recheck",
 New_label			: "New Label...",
 Remove_label			: "Remove Label",
 Labels 			: "Labels",
 Remove 			: "Remove",
 Delete_data			: "Delete Data",
 Remove_and			: "Remove and...",
 Details			: "Details...",
 Properties			: "Properties...",
 of				: "of", //this two creates line
 connected			: "connected", //  XX of YY connected
 High_priority			: "High",
 Normal_priority		: "Normal",
 Low_priority			: "Low",
 Dont_download			: "Don't Download",
 Files				: "Files",
 Logger 			: "Log",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Loading...",
 Torrent_file			: "Torrent file",
 Torrent_URL			: "Torrent URL",
 Torrent_properties		: "Torrent Properties",
 Trackers			: "Trackers",
 Bandwidth_sett 		: "Bandwidth Settings",
 Number_ul_slots		: "Number of upload slots",
 Peer_ex			: "Peer Exchange",
 Enter_label_prom		: "Enter the new label for the selected torrents",
 Remove_torrents		: "Remove Torrent(s)",
 Rem_torrents_prompt		: "Do you really want to remove the selected torrent(s)?",
 All				: "All",
 Active 			: "Active",
 Inactive			: "Inactive",
 No_label			: "No Label",
 Transfer			: "Transfer",
 Time_el			: "Time Elapsed",
 Share_ratio			: "Share Ratio",
 Down_speed			: "Download Speed",
 Ul_speed			: "Upload Speed",
 Wasted 			: "Wasted",
 Tracker			: "Tracker",
 Track_URL			: "Tracker URL",
 Track_status			: "Tracker Status",
 Created_on			: "Created On",
 Save_as			: "Save As",
 Comment			: "Comment",
 add_button			: "Add File",
 add_url			: "Add URL",
 ok				: "OK",
 Cancel 			: "Cancel",
 mnu_add			: "Add Torrent",
 mnu_remove			: "Remove",
 mnu_start			: "Start",
 mnu_pause			: "Pause",
 mnu_stop			: "Stop",
 mnu_rss			: "RSS Downloader",
 mnu_settings			: "Settings",
 mnu_search			: "Search",
 mnu_lang			: "Language",
 torrent_add			: "Add Torrent", /*Caption of torrent add box*/
 time_w 			: "w ", /*for x weeks*/
 time_d 			: "d ", /*for x days remaining*/
 time_h 			: "h ", /*for x hours remaining*/
 time_m 			: "m ", /*for x minutes remaining*/
 time_s 			: "s ", /*for x seconds remaining*/
 Base_directory 		: "Directory",
 Number_Peers_min		: "Minimum number of peers",
 Number_Peers_max		: "Maximum number of peers",
 Tracker_Numwant		: "Wished number of peers",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting 		: "Other Limitations",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Maximum memory usage",
 Glob_max_files 		: "Maximum number of open files",
 Glob_max_http			: "Maximum number of open http connections",
 Other_sett			: "Other",
 Directory_For_Dl		: "Default directory for downloads",
 Check_hash			: "Check hash after download",
 Hash				: "Hash",
 DisableTracker 		: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Help",
 Speed				: "Speed",
 Dont_add_tname 		: "Don't add torrent's name to path",
 Free_Disk_Space		: "Free Disk Space",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath 		: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "Help",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList 			: "As List",
 AsTree 			: "As Tree",
 Group				: "Group",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go 			: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limit",
 speedList			: "Speed Popup List (comma-separated)",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser 		: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast 		: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No 			: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details 		: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 badTempPath 			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue Files Recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.0.4.tar.gz: ruTorrent-4.0.4/lang/en.js <==
﻿/*
 * English language file.
 *
 * Initial Author: Artem Lopata (mod-s@yandex.ru)
 *
 * Author: 
 */

var theUILang =
{
 General			: "General",
 Downloads			: "Downloads",
 Connection			: "Connection",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Advanced",
 User_Interface			: "User Interface",
 Confirm_del_torr		: "Confirm when deleting torrents",
 Update_GUI_every		: "Update GUI every",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternate list background colour",
 Show_cat_start			: "Show categories on startup",
 Show_det_start			: "Show details on startup",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "Don't start the download automatically",
 Listening_Port			: "Listening Port",
 Port_f_incom_conns		: "Port used for incoming connections",
 Rnd_port_torr_start		: "Randomize port each time rTorrent starts",
 Type				: "Type",
 Bandwidth_Limiting		: "Bandwidth Limiting",
 Global_max_upl			: "Global maximum upload rate",
 unlimited			: "Unlimited",
 Glob_max_downl			: "Global maximum download rate",
 Add_bittor_featrs		: "Additional BitTorrent Features",
 En_DHT_ntw			: "Enable DHT Network",
 Peer_exch			: "Peer Exchange",
 Ip_report_track		: "IP/Hostname to report to tracker",
 Disabled			: "Disabled",
 Enabled			: "Enabled",
 ruTorrent_settings		: "Settings",
 Doesnt_support			: "ruTorrent does not support your browser.",
 Name				: "Name",
 Status				: "Status",
 Size				: "Size",
 Done				: "Done",
 Downloaded			: "Downloaded",
 Uploaded			: "Uploaded",
 Ratio				: "Ratio",
 DL				: "DL",
 UL				: "UL",
 ETA				: "ETA",
 Label				: "Label",
 Peers				: "Peers",
 Seeds				: "Seeds",
 Remaining			: "Remaining",
 Priority			: "Priority",
 Not_torrent_file		: "The file must be a .torrent file.",
 Pausing			: "Pausing",
 Seeding			: "Seeding",
 Downloading			: "Downloading",
 Checking			: "Checking",
 Error				: "Error",
 Queued				: "Queued",
 Finished			: "Completed",
 Stopped			: "Stopped",
 Request_timed_out		: "The request to rTorrent has timed out.",
 Start				: "Start",
 Pause				: "Pause",
 Stop				: "Stop",
 Force_recheck			: "Force Recheck",
 New_label			: "New Label...",
 Remove_label			: "Remove Label",
 Labels				: "Labels",
 Remove				: "Remove",
 Delete_data			: "Delete Data",
 Remove_and			: "Remove And",
 Details			: "Details...",
 Properties			: "Properties...",
 of				: "of", // this two creates line
 connected			: "connected", // XX of YY connected
 High_priority			: "High",
 Normal_priority		: "Normal",
 Low_priority			: "Low",
 Dont_download			: "Don't Download",
 Files				: "Files",
 Logger				: "Log",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Loading...",
 Torrent_file			: "Torrent file",
 Torrent_URL			: "Torrent URL",
 Torrent_properties		: "Torrent Properties",
 Trackers			: "Trackers",
 Bandwidth_sett			: "Bandwidth Settings",
 Number_ul_slots		: "Number of upload slots",
 Peer_ex			: "Peer Exchange",
 Enter_label_prom		: "Enter the new label for the selected torrents",
 Remove_torrents		: "Remove Torrent(s)",
 Rem_torrents_prompt		: "Do you really want to remove the selected torrent(s)?",
 All				: "All",
 Active				: "Active",
 Inactive			: "Inactive",
 No_label			: "No Label",
 Transfer			: "Transfer",
 Time_el			: "Time Elapsed",
 Share_ratio			: "Share Ratio",
 Down_speed			: "Download Speed",
 Ul_speed			: "Upload Speed",
 Wasted				: "Wasted",
 Tracker			: "Tracker",
 Track_URL			: "Tracker URL",
 Track_status			: "Tracker Status",
 Created_on			: "Created On",
 Save_as			: "Save As",
 Comment			: "Comment",
 add_button			: "Add File",
 add_url			: "Add URL",
 ok				: "OK",
 Cancel				: "Cancel",
 mnu_add			: "Add Torrent",
 mnu_remove			: "Remove",
 mnu_start			: "Start",
 mnu_pause			: "Pause",
 mnu_stop			: "Stop",
 mnu_rss			: "RSS Downloader",
 mnu_settings			: "Settings",
 mnu_search			: "Search",
 mnu_lang			: "Language",
 torrent_add			: "Add Torrent", /*Caption of torrent add box*/
 time_w				: "w ", /*for x weeks*/
 time_d				: "d ", /*for x days remaining*/
 time_h				: "h ", /*for x hours remaining*/
 time_m				: "m ", /*for x minutes remaining*/
 time_s				: "s ", /*for x seconds remaining*/
 Base_directory			: "Directory",
 Number_Peers_min		: "Minimum number of peers",
 Number_Peers_max		: "Maximum number of peers",
 Tracker_Numwant		: "Wished number of peers",
 Number_Peers_For_Seeds_min	: "Minimum number of peers for seeding",
 Number_Peers_For_Seeds_max	: "Maximum number of peers for seeding",
 Enable_port_open		: "Open listening port",
 dht_port			: "UDP port to use for DHT",
 Other_Limiting			: "Other Limitations",
 Number_dl_slots		: "Number of download slots",
 Glob_max_memory		: "Maximum memory usage",
 Glob_max_files			: "Maximum number of open files",
 Glob_max_http			: "Maximum number of open http connections",
 Open_label         : "Open",
 Other_sett			: "Other",
 Directory_For_Dl		: "Default directory for downloads",
 Check_hash			: "Check hash after download",
 Hash				: "Hash",
 DisableTracker			: "Disable",
 EnableTracker			: "Enable",
 ClientVersion			: "Client",
 Flags				: "Flags",
 ReqTimeout			: "Request timeout",
 GetTrackerMessage		: "Receive messages from tracker",
 Help				: "Help",
 Speed				: "Speed",
 Dont_add_tname			: "Don't add torrent's name to path",
 Free_Disk_Space		: "Free Disk Space",
 badXMLRPCVersion		: "rTorrent is compiled with incorrect version of xmlrpc-c library, without i8 support. Version must be >= 1.11. Some functionality will be unavailable.",
 badLinkTorTorrent		: "No connection to rTorrent. Check if it is really running. Check $scgi_port and $scgi_host settings in config.php and scgi_port in rTorrent configuration file.",
 badUploadsPath			: "Webserver user doesn't have read/write/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 badSettingsPath		: "Webserver user doesn't have read/write/execute access to the settings directory. ruTorrent settings cannot be saved.",
 mnu_help			: "Help",
 badUploadsPath2		: "rTorrent user must have read/execute access to the torrents directory. You cannot add torrents via ruTorrent.",
 View				: "View",
 AsList				: "As List",
 AsTree				: "As Tree",
 Group				: "Group",
 SuperSeed			: "Super-seed",
 badTestPath			: "rTorrent user must have read/execute access to the file ./test.sh",
 badSettingsPath2		: "rTorrent user must have read/write/execute access to the settings directory.",
 scrapeDownloaded		: "Downloaded",
 Total				: "Total",
 PCRENotFound			: "PHP PCRE module is not installed. ruTorrent will not work.",
 addTorrentSuccess		: "Torrent was added successfully.",
 addTorrentFailed		: "Failed to add torrent.",
 pnlState			: "State",
 newLabel			: "New Label",
 enterLabel			: "Enter Label",
 UIEffects			: "Show effects for UI elements",
 Plugins			: "Plugins",
 plgName			: "Name",
 plgStatus			: "Status",
 plgLoaded			: "Loaded",
 plgDisabled			: "Not loaded",
 plgVersion			: "Version",
 plgAuthor			: "Author",
 plgDescr			: "Description",
 mnu_go				: "Go",
 pluginCantStart		: "Plugin failed to start.",
 doFastResume			: "Fast resume",
 innerSearch			: "Local Torrents",
 removeTeg			: "Remove tag",
 errMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Plugin will not work.",
 warnMustBeInSomeHost		: "ruTorrent and rTorrent must be installed on the same host. Some functionality will be unavailable.",
 plgShutdown			: "Unload",
 limit				: "Limit",
 speedList			: "Speed Popup List (comma-separated)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Clear",
 dontShowTimeouts		: "Ignore message about timeouts",
 fullTableRender		: "Full render of large tables",
 showScrollTables		: "Show table contents while scrolling",
 idNotFound			: "rTorrent user can't access 'id' program. Some functionality will be unavailable.",
 gzipNotFound			: "Webserver user can't access 'gzip' program. ruTorrent will not work.",
 cantObtainUser			: "ruTorrent cannot determine the UID of rTorrent user. Some functionality will be unavailable.",
 retryOnErrorTitle		: "If rTorrent is not available try again after",
 retryOnErrorList		: { 0: "Don't try again", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent user can't access 'stat' program. Some functionality will be unavailable.",
 statNotFoundW			: "Webserver user can't access 'stat' program. Some functionality will be unavailable.",
 badrTorrentVersion		: "Plugin requires rTorrent version >=",
 badPHPVersion			: "Plugin requires PHP version >=",
 rTorrentExternalNotFoundError	: "Plugin will not work. rTorrent user can't access external program",
 rTorrentExternalNotFoundWarning: "Some functionality will be unavailable. rTorrent user can't access external program",
 webExternalNotFoundError	: "Plugin will not work. Webserver user can't access external program",
 webExternalNotFoundWarning	: "Some functionality will be unavailable. Webserver user can't access external program",
 rTorrentBadScriptPath		: "Plugin will not work. rTorrent user must have read/execute access to the file",
 rTorrentBadPHPScriptPath	: "Plugin will not work. rTorrent user must have read access to the file",
 dependenceError		: "Plugin will not work. It requires plugin(s)",
 peerAdd			: "Add Peer...",
 peerBan			: "Ban",
 peerKick			: "Kick",
 peerSnub			: "Snub",
 peerDetails			: "Details",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "Enter IP/Hostname[:port]",
 noTorrentList			: "Torrent list not yet available, connection to rTorrent not established.",
 yes				: "yes",
 no				: "no",
 DateFormat			: "Date format",
 DLStrategy			: "Download Strategy",
 prioritizeFirst		: "Leading Chunk First",
 prioritizeLast			: "Trailing Chunk First",
 prioritizeNormal		: "Normal",
 updateTracker			: "Update Trackers",
 scrapeUpdate			: "Last Updated",
 trkInterval			: "Interval",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showStateLabelSize		: "Show state size",
 showLabelSize			: "Show label size",
 showSearchLabelSize		: "Show search size",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "PHP directive register_argc_argv is set to OFF. Change to ON, otherwise some plugins won't work correctly.",
 addTorrentFailedURL		: "Failed to add torrent. Can't retrieve URL.",
 addTorrentFailedFile		: "Failed to add torrent. The retrieved content is not a valid torrent file.",
 addTorrentFailedDirectory	: "Failed to add torrent. Incorrect downloads directory was specified.",
 plgLaunch			: "Launch",
 plgLocked			: "Mandatory",
 phpExtensionNotFoundWarning	: "Some functionality will be unavailable. PHP extension must be installed",
 phpExtensionNotFoundError	: "Plugin will not work. PHP extension must be installed",
 trkPrivate			: "Private",
 dontSet			: "Don't set",
 webBadSessionError		: "Plugin will not work. Webserver user must have execute access to the rtorrent session directory",
 webBadSessionWarning		: "Some functionality will be unavailable. Webserver user must have execute access to the rtorrent session directory",
 Developers			: "Developers",
 Check_new_version		: "Check new version",
 here				: "here",
 Num_No				: "No.", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "This screen",
 About_program			: "About ruTorrent",
 Toggle_menu			: "Toggle menu",
 Toggle_details			: "Toggle details",
 Toggle_categories		: "Toggle categories",
 Delete_current_torrents	: "Delete current torrent(s)",
 Select_all			: "Select all",
 Deselect_all			: "Deselect all",
 showSpeedInTitle		: "Show speed in the title",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "Webserver user doesn't have read/write/execute access to the tmp directory. ruTorrent will not work.",
 badTempPath2			: "rTorrent user must have read/execute access to the tmp directory. ruTorrent will not work.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
